# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ocellus_types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13ocellus_types.proto\x12\x07ocellus\"\xae\x08\n\x04\x44\x61ta\x12+\n\x07\x63\x61meras\x18\x01 \x03(\x0b\x32\x1a.ocellus.Data.CamerasEntry\x12-\n\x08\x63ontours\x18\x02 \x03(\x0b\x32\x1b.ocellus.Data.ContoursEntry\x12\'\n\x05items\x18\x03 \x03(\x0b\x32\x18.ocellus.Data.ItemsEntry\x12\x31\n\nrgbaImages\x18\x04 \x03(\x0b\x32\x1d.ocellus.Data.RgbaImagesEntry\x12\x33\n\x0bpointClouds\x18\x05 \x03(\x0b\x32\x1e.ocellus.Data.PointCloudsEntry\x12-\n\x08\x64\x65\x63imals\x18\x06 \x03(\x0b\x32\x1b.ocellus.Data.DecimalsEntry\x12-\n\x08integers\x18\x07 \x03(\x0b\x32\x1b.ocellus.Data.IntegersEntry\x12+\n\x07strings\x18\x08 \x03(\x0b\x32\x1a.ocellus.Data.StringsEntry\x12/\n\tpositions\x18\t \x03(\x0b\x32\x1c.ocellus.Data.PositionsEntry\x12\x33\n\x0bquaternions\x18\n \x03(\x0b\x32\x1e.ocellus.Data.QuaternionsEntry\x1a?\n\x0c\x43\x61merasEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.ocellus.Camera:\x02\x38\x01\x1a\x42\n\rContoursEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.ocellus.Contours:\x02\x38\x01\x1a<\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.ocellus.Items:\x02\x38\x01\x1a\x31\n\x0fRgbaImagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10PointCloudsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rDecimalsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a/\n\rIntegersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a.\n\x0cStringsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x43\n\x0ePositionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.ocellus.Position:\x02\x38\x01\x1aG\n\x10QuaternionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.ocellus.Quaternion:\x02\x38\x01\"3\n\x05\x43olor\x12\t\n\x01r\x18\x01 \x01(\x02\x12\t\n\x01g\x18\x02 \x01(\x02\x12\t\n\x01\x62\x18\x03 \x01(\x02\x12\t\n\x01\x61\x18\x04 \x01(\x02\"9\n\tDimension\x12\r\n\x05width\x18\x01 \x01(\x02\x12\x0e\n\x06height\x18\x02 \x01(\x02\x12\r\n\x05\x64\x65pth\x18\x03 \x01(\x02\"M\n\x08Position\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x12 \n\x05local\x18\x04 \x01(\x0b\x32\x11.ocellus.Position\"\\\n\nQuaternion\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x12\t\n\x01w\x18\x04 \x01(\x02\x12\"\n\x05local\x18\x05 \x01(\x0b\x32\x13.ocellus.Quaternion\"\\\n\x0b\x45ulerAngles\x12\x0b\n\x03yaw\x18\x01 \x01(\x02\x12\r\n\x05pitch\x18\x02 \x01(\x02\x12\x0c\n\x04roll\x18\x03 \x01(\x02\x12#\n\x05local\x18\x04 \x01(\x0b\x32\x14.ocellus.EulerAngles\"d\n\x0c\x45xtremePoint\x12#\n\x08position\x18\x01 \x01(\x0b\x32\x11.ocellus.Position\x12\x1d\n\x05pixel\x18\x02 \x01(\x0b\x32\x0e.ocellus.Point\x12\x10\n\x08\x61\x63\x63uracy\x18\x03 \x01(\x02\"A\n\tHistogram\x12\x0f\n\x03red\x18\x01 \x03(\x05\x42\x02\x10\x01\x12\x11\n\x05green\x18\x02 \x03(\x05\x42\x02\x10\x01\x12\x10\n\x04\x62lue\x18\x03 \x03(\x05\x42\x02\x10\x01\"\x8a\x05\n\x04Item\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x0cparentCamera\x18\x03 \x01(\x0b\x32\x0f.ocellus.Camera\x12\x0e\n\x06weight\x18\x04 \x01(\x02\x12\x12\n\nconfidence\x18\x05 \x01(\x02\x12\x1d\n\x05\x63olor\x18\x06 \x01(\x0b\x32\x0e.ocellus.Color\x12\x16\n\x0e\x64\x65ltaTimestamp\x18\x07 \x01(\x03\x12%\n\tdimension\x18\x08 \x01(\x0b\x32\x12.ocellus.Dimension\x12#\n\x08position\x18\t \x01(\x0b\x32\x11.ocellus.Position\x12\'\n\nquaternion\x18\n \x01(\x0b\x32\x13.ocellus.Quaternion\x12)\n\x0b\x65ulerAngles\x18\x0b \x01(\x0b\x32\x14.ocellus.EulerAngles\x12\x37\n\rextremePoints\x18\x0c \x03(\x0b\x32 .ocellus.Item.ExtremePointsEntry\x12\x1f\n\x08\x63hildren\x18\r \x03(\x0b\x32\r.ocellus.Item\x12$\n\x08pathPlan\x18\x0e \x03(\x0b\x32\x12.ocellus.PathPoint\x12!\n\x07\x63ontour\x18\x0f \x01(\x0b\x32\x10.ocellus.Contour\x12\x1d\n\x05pixel\x18\x10 \x01(\x0b\x32\x0e.ocellus.Point\x12%\n\thistogram\x18\x11 \x01(\x0b\x32\x12.ocellus.Histogram\x12\x10\n\x08\x61\x63\x63uracy\x18\x12 \x01(\x02\x1aK\n\x12\x45xtremePointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.ocellus.ExtremePoint:\x02\x38\x01\"\xb8\x01\n\x06\x43\x61mera\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x08position\x18\x02 \x01(\x0b\x32\x11.ocellus.Position\x12\'\n\nquaternion\x18\x03 \x01(\x0b\x32\x13.ocellus.Quaternion\x12)\n\x0b\x65ulerAngles\x18\x04 \x01(\x0b\x32\x14.ocellus.EulerAngles\x12\'\n\nintrinsics\x18\x05 \x01(\x0b\x32\x13.ocellus.Intrinsics\"\xb6\x01\n\tPathPoint\x12\x11\n\tdeltaTime\x18\x01 \x01(\x03\x12#\n\x08position\x18\x02 \x01(\x0b\x32\x11.ocellus.Position\x12)\n\x0b\x65ulerAngles\x18\x03 \x01(\x0b\x32\x14.ocellus.EulerAngles\x12\'\n\nquaternion\x18\x04 \x01(\x0b\x32\x13.ocellus.Quaternion\x12\x1d\n\x05pixel\x18\x05 \x01(\x0b\x32\x0e.ocellus.Point\"\xcf\x02\n\nIntrinsics\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\x0b\n\x03ppx\x18\x03 \x01(\x02\x12\x0b\n\x03ppy\x18\x04 \x01(\x02\x12\n\n\x02\x66x\x18\x05 \x01(\x02\x12\n\n\x02\x66y\x18\x06 \x01(\x02\x12-\n\x05model\x18\x07 \x01(\x0e\x32\x1e.ocellus.Intrinsics.Distortion\x12\x0e\n\x06\x63oeffs\x18\x08 \x03(\x02\x12\x0b\n\x03\x66ov\x18\t \x03(\x02\"\xa3\x01\n\nDistortion\x12\x13\n\x0f\x44ISTORTION_NONE\x10\x00\x12%\n!DISTORTION_MODIFIED_BROWN_CONRADY\x10\x01\x12$\n DISTORTION_INVERSE_BROWN_CONRADY\x10\x02\x12\x15\n\x11\x44ISTORTION_FTHETA\x10\x03\x12\x1c\n\x18\x44ISTORTION_BROWN_CONRADY\x10\x04\"\x1d\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\"(\n\x06Points\x12\x1e\n\x06points\x18\x01 \x03(\x0b\x32\x0e.ocellus.Point\"e\n\x07\x43ontour\x12%\n\x0couterContour\x18\x01 \x01(\x0b\x32\x0f.ocellus.Points\x12%\n\x0choleContours\x18\x02 \x03(\x0b\x32\x0f.ocellus.Points\x12\x0c\n\x04\x61rea\x18\x03 \x01(\x01\".\n\x08\x43ontours\x12\"\n\x08\x63ontours\x18\x01 \x03(\x0b\x32\x10.ocellus.Contour\"$\n\x05Items\x12\x1b\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\r.ocellus.Item\";\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"-\n\nVector3Dim\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"U\n\x0fPageanationData\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x05\x12\n\n\x02to\x18\x02 \x01(\x05\x12\x0b\n\x03max\x18\x03 \x01(\x05\x12\r\n\x05limit\x18\x04 \x01(\x05\x12\x0c\n\x04path\x18\x05 \x01(\t\"m\n\x08\x46ileData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61teTime\x18\x02 \x01(\t\x12\x10\n\x08mimeType\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x03\x12\x13\n\x0bisDirectory\x18\x05 \x01(\x08\x12\x0c\n\x04path\x18\x06 \x01(\t\"_\n\x0cGlobalConfig\x12%\n\x08position\x18\x01 \x01(\x0b\x32\x13.ocellus.Vector3Dim\x12(\n\x0borientation\x18\x02 \x01(\x0b\x32\x13.ocellus.Vector3Dim*\xa1\x02\n\x08\x44\x61taType\x12\x15\n\x11\x44\x41TA_TYPE_UNKNOWN\x10\x00\x12\x14\n\x10\x44\x41TA_TYPE_CAMERA\x10\x01\x12\x16\n\x12\x44\x41TA_TYPE_CONTOURS\x10\x02\x12\x13\n\x0f\x44\x41TA_TYPE_ITEMS\x10\x03\x12\x18\n\x14\x44\x41TA_TYPE_RGBA_IMAGE\x10\x04\x12\x18\n\x14\x44\x41TA_TYPE_POINTCLOUD\x10\x05\x12\x15\n\x11\x44\x41TA_TYPE_DECIMAL\x10\x06\x12\x15\n\x11\x44\x41TA_TYPE_INTEGER\x10\x07\x12\x14\n\x10\x44\x41TA_TYPE_STRING\x10\x08\x12\x13\n\x0f\x44\x41TA_TYPE_ERROR\x10\t\x12\x16\n\x12\x44\x41TA_TYPE_POSITION\x10\n\x12\x16\n\x12\x44\x41TA_TYPE_ROTATION\x10\x0b\x42`\n\x11ocellus.api.typesB\x0fOcellusApiTypesP\x01Z\x1egithub.com/byte-motion/ocellus\xa2\x02\x03OAT\xaa\x02\x11Ocellus.Api.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ocellus_types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021ocellus.api.typesB\017OcellusApiTypesP\001Z\036github.com/byte-motion/ocellus\242\002\003OAT\252\002\021Ocellus.Api.Types'
  _DATA_CAMERASENTRY._options = None
  _DATA_CAMERASENTRY._serialized_options = b'8\001'
  _DATA_CONTOURSENTRY._options = None
  _DATA_CONTOURSENTRY._serialized_options = b'8\001'
  _DATA_ITEMSENTRY._options = None
  _DATA_ITEMSENTRY._serialized_options = b'8\001'
  _DATA_RGBAIMAGESENTRY._options = None
  _DATA_RGBAIMAGESENTRY._serialized_options = b'8\001'
  _DATA_POINTCLOUDSENTRY._options = None
  _DATA_POINTCLOUDSENTRY._serialized_options = b'8\001'
  _DATA_DECIMALSENTRY._options = None
  _DATA_DECIMALSENTRY._serialized_options = b'8\001'
  _DATA_INTEGERSENTRY._options = None
  _DATA_INTEGERSENTRY._serialized_options = b'8\001'
  _DATA_STRINGSENTRY._options = None
  _DATA_STRINGSENTRY._serialized_options = b'8\001'
  _DATA_POSITIONSENTRY._options = None
  _DATA_POSITIONSENTRY._serialized_options = b'8\001'
  _DATA_QUATERNIONSENTRY._options = None
  _DATA_QUATERNIONSENTRY._serialized_options = b'8\001'
  _HISTOGRAM.fields_by_name['red']._options = None
  _HISTOGRAM.fields_by_name['red']._serialized_options = b'\020\001'
  _HISTOGRAM.fields_by_name['green']._options = None
  _HISTOGRAM.fields_by_name['green']._serialized_options = b'\020\001'
  _HISTOGRAM.fields_by_name['blue']._options = None
  _HISTOGRAM.fields_by_name['blue']._serialized_options = b'\020\001'
  _ITEM_EXTREMEPOINTSENTRY._options = None
  _ITEM_EXTREMEPOINTSENTRY._serialized_options = b'8\001'
  _DATATYPE._serialized_start=3682
  _DATATYPE._serialized_end=3971
  _DATA._serialized_start=33
  _DATA._serialized_end=1103
  _DATA_CAMERASENTRY._serialized_start=519
  _DATA_CAMERASENTRY._serialized_end=582
  _DATA_CONTOURSENTRY._serialized_start=584
  _DATA_CONTOURSENTRY._serialized_end=650
  _DATA_ITEMSENTRY._serialized_start=652
  _DATA_ITEMSENTRY._serialized_end=712
  _DATA_RGBAIMAGESENTRY._serialized_start=714
  _DATA_RGBAIMAGESENTRY._serialized_end=763
  _DATA_POINTCLOUDSENTRY._serialized_start=765
  _DATA_POINTCLOUDSENTRY._serialized_end=815
  _DATA_DECIMALSENTRY._serialized_start=817
  _DATA_DECIMALSENTRY._serialized_end=864
  _DATA_INTEGERSENTRY._serialized_start=866
  _DATA_INTEGERSENTRY._serialized_end=913
  _DATA_STRINGSENTRY._serialized_start=915
  _DATA_STRINGSENTRY._serialized_end=961
  _DATA_POSITIONSENTRY._serialized_start=963
  _DATA_POSITIONSENTRY._serialized_end=1030
  _DATA_QUATERNIONSENTRY._serialized_start=1032
  _DATA_QUATERNIONSENTRY._serialized_end=1103
  _COLOR._serialized_start=1105
  _COLOR._serialized_end=1156
  _DIMENSION._serialized_start=1158
  _DIMENSION._serialized_end=1215
  _POSITION._serialized_start=1217
  _POSITION._serialized_end=1294
  _QUATERNION._serialized_start=1296
  _QUATERNION._serialized_end=1388
  _EULERANGLES._serialized_start=1390
  _EULERANGLES._serialized_end=1482
  _EXTREMEPOINT._serialized_start=1484
  _EXTREMEPOINT._serialized_end=1584
  _HISTOGRAM._serialized_start=1586
  _HISTOGRAM._serialized_end=1651
  _ITEM._serialized_start=1654
  _ITEM._serialized_end=2304
  _ITEM_EXTREMEPOINTSENTRY._serialized_start=2229
  _ITEM_EXTREMEPOINTSENTRY._serialized_end=2304
  _CAMERA._serialized_start=2307
  _CAMERA._serialized_end=2491
  _PATHPOINT._serialized_start=2494
  _PATHPOINT._serialized_end=2676
  _INTRINSICS._serialized_start=2679
  _INTRINSICS._serialized_end=3014
  _INTRINSICS_DISTORTION._serialized_start=2851
  _INTRINSICS_DISTORTION._serialized_end=3014
  _POINT._serialized_start=3016
  _POINT._serialized_end=3045
  _POINTS._serialized_start=3047
  _POINTS._serialized_end=3087
  _CONTOUR._serialized_start=3089
  _CONTOUR._serialized_end=3190
  _CONTOURS._serialized_start=3192
  _CONTOURS._serialized_end=3238
  _ITEMS._serialized_start=3240
  _ITEMS._serialized_end=3276
  _ERROR._serialized_start=3278
  _ERROR._serialized_end=3337
  _VECTOR3DIM._serialized_start=3339
  _VECTOR3DIM._serialized_end=3384
  _PAGEANATIONDATA._serialized_start=3386
  _PAGEANATIONDATA._serialized_end=3471
  _FILEDATA._serialized_start=3473
  _FILEDATA._serialized_end=3582
  _GLOBALCONFIG._serialized_start=3584
  _GLOBALCONFIG._serialized_end=3679
# @@protoc_insertion_point(module_scope)
